==> down.php?SDK=HIVE_SDK_Android_v4.15.1.4_withCore.zip: Sample/app/src/main/java/com/hive/sample/MainActivity.kt <==
package com.hive.sample


import android.annotation.TargetApi
import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Bundle
import androidx.viewpager.widget.ViewPager
import androidx.viewpager.widget.ViewPager.OnPageChangeListener
import android.util.Log
import android.view.View
import android.view.View.*
import com.com2us.hivesdk.normal.freefull.google.global.android.common.R
import com.gcp.hivecore.Configuration.ZoneType
import com.hive.Configuration
import com.hive.HiveActivity
import com.hive.base.Android
import com.hive.sample.uihelper.ViewPagerManager


/**
 * HIVE SDK 샘플 예제의 메인 Activity
 *
 * @author ryuvsken
 */
class MainActivity : Activity() {

    private var pageChangeListener: OnPageChangeListener? = null

    override fun onMultiWindowModeChanged(isInMultiWindowMode: Boolean, newConfig: android.content.res.Configuration) {
        super.onMultiWindowModeChanged(isInMultiWindowMode, newConfig)

        HiveActivity.onMultiWindowModeChanged(this, isInMultiWindowMode, newConfig)
    }

    override fun onConfigurationChanged(newConfig: android.content.res.Configuration) {
        super.onConfigurationChanged(newConfig)

        HiveActivity.onConfigurationChanged(this, newConfig)

    }

    override fun attachBaseContext(newBase: Context?) {
        newBase?.let { super.attachBaseContext(HiveActivity.attachBaseContext(newBase)) }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        Log.i("MainActivity", "onCreate")

        Log.e("MainActivity", "===== mcc: ${this.resources.configuration.mcc}")

        this.requestWindowFeature(android.view.Window.FEATURE_NO_TITLE)

        this.initUi()

        HiveActivity.onCreate(this, savedInstanceState)
    }

    override fun onStart() {
        super.onStart()

        HiveActivity.onStart(this)
    }

    override fun onRestart() {
        super.onRestart()

        HiveActivity.onRestart(this)
    }

    override fun onResume() {
        super.onResume()

        Log.i("MainActivity", "onResume")

        HiveActivity.onResume(this)
    }


    override fun onPause() {

        HiveActivity.onPause(this)

        super.onPause()
    }

    override fun onStop() {
        HiveActivity.onStop(this)

        super.onStop()
    }

    override fun onDestroy() {
        HiveActivity.onDestroy(this)

        releaseViewPager()

        super.onDestroy()
    }

    override fun onWindowFocusChanged(hasFocus: Boolean) {
        super.onWindowFocusChanged(hasFocus)

        HiveActivity.onWindowFocusChanged(this, hasFocus)
    }


    override fun onNewIntent(intent: Intent?) {
        super.onNewIntent(intent)

        Log.i("MainActivity", "onNewIntent")
        HiveActivity.onNewIntent(this, intent)
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        HiveActivity.onActivityResult(this, requestCode, resultCode, data)
        super.onActivityResult(requestCode, resultCode, data)
    }


    // Android SDK 6.0 (android-23) API over
    @TargetApi(23)
    override fun onRequestPermissionsResult(requestCode: Int, permissions: Array<String>, grantResults: IntArray) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults)

        HiveActivity.onRequestPermissionsResult(this, requestCode, permissions, grantResults)
    }


    override fun onSaveInstanceState(outState: Bundle) {
        super.onSaveInstanceState(outState)

        HiveActivity.onSaveInstanceState(this, outState)
    }

    override fun onBackPressed() {
        super.onBackPressed()
    }


    private fun initUi() {

        setContentView(R.layout.main_activity)


        // HiveSDK 설정 대화 상자 노출
        val configurationDialog = ConfigurationDialog(this)
        configurationDialog.showConfigurationDialog(object : ConfigurationDialog.ConfigurationDialogListener {

            override fun onConfigurationSelect(appId: String, hiveCertificationKey: String, zoneType: ZoneType, themeType: com.hive.ui.Configuration.HiveTheme, gameLanguage: String, gameServerId: String, isLogging: Boolean, loggingUserId: String?, isRemoteLogging: Boolean, isRemoteDetailLogging: Boolean, isAgeGateU13: Boolean) {
                // 설정 대화 상자에서 설정이 완료되면 HiveSDK 설정 을 수행
                Configuration.appId = appId
                Configuration.hiveCertificationKey = hiveCertificationKey
                Configuration.zone = zoneType
                Configuration.hiveTheme = themeType
                Configuration.gameLanguage = gameLanguage
                Configuration.serverId = gameServerId
                Configuration.useLog = isLogging
//                Configuration.setLogUserId(loggingUserId)
//                Configuration.setIsRemoteLogging(isRemoteLogging)
//                Configuration.setIsRemoteDetailLogging(isRemoteDetailLogging)
                Configuration.ageGateU13 = isAgeGateU13

                Android.runOnMainThread(Runnable { buildViewPager() })
            }
        })
    }

    private fun releaseViewPager() {

        val viewPager = ViewPagerManager.getViewPager()
        if (viewPager != null) {
            viewPager.removeOnPageChangeListener(pageChangeListener!!)

            ViewPagerManager.releaseViewPager()
        }
    }

    private fun buildViewPager() {

        var view: View

        // AuthV4 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_authv4, null)
        ViewPagerManager.addView(AuthV4TestView(this, view, "AuthV4 >>"))

        // AuthV4Helper 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_authv4_helper, null)
        ViewPagerManager.addView(AuthV4HelperTestView(this, view, "AuthV4 >>"))

        // ProviderGoogle 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_provider, null)
        ViewPagerManager.addView(ProviderTestView(this, view, "Provider >>"))

        // 인증 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_auth, null)
        ViewPagerManager.addView(AuthTestView(this, view, "AuthV1 >>"))


        // 소셜 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_social, null)
        ViewPagerManager.addView(SocialTestView(this, view, "<< Social >>"))


        // 프로모션 뷰의 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_promotion, null)
        ViewPagerManager.addView(PromotionTestView(this, view, "<< Promotion >>"))


        // 푸시 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_push, null)
        ViewPagerManager.addView(PushTestView(this, view, "<< Push Notification >>"))


        // IAP (빌링) 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_iap, null)
        ViewPagerManager.addView(IAPTestView(this, view, "<< IAP >>"))


        // IAPV4 (빌링) 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_iapv4, null)
        ViewPagerManager.addView(IAPV4TestView(this, view, "<< IAPV4 >>"))


        // Analytics 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_analytics, null)
        ViewPagerManager.addView(AnalyticsTestView(this, view, "Analytics >>"))


        val viewPager = findViewById<View>(R.id.main_pager) as androidx.viewpager.widget.ViewPager
        viewPager.adapter = ViewPagerManager
        ViewPagerManager.setViewPager(this, viewPager)


        //		viewPager.setOnPageChangeListener(new OnPageChangeListener() {

        pageChangeListener = object : OnPageChangeListener {

            override fun onPageSelected(position: Int) {

                ViewPagerManager.onPageChange(position)
            }

            override fun onPageScrolled(arg0: Int, arg1: Float, arg2: Int) {}

            override fun onPageScrollStateChanged(arg0: Int) {}

        }.also {
            viewPager.addOnPageChangeListener(it)
        }

    }
}

==> down.php?SDK=HIVE_SDK_Android_v4.15.3_withCore.zip: Sample/app/src/main/java/com/hive/sample/MainActivity.kt <==
package com.hive.sample


import android.annotation.TargetApi
import android.app.Activity
import android.content.Context
import android.content.Intent
import android.os.Bundle
import androidx.viewpager.widget.ViewPager
import androidx.viewpager.widget.ViewPager.OnPageChangeListener
import android.util.Log
import android.view.View
import android.view.View.*
import com.com2us.hivesdk.normal.freefull.google.global.android.common.R
import com.gcp.hivecore.Configuration.ZoneType
import com.hive.Configuration
import com.hive.HiveActivity
import com.hive.base.Android
import com.hive.sample.uihelper.ViewPagerManager


/**
 * HIVE SDK 샘플 예제의 메인 Activity
 *
 * @author ryuvsken
 */
class MainActivity : Activity() {

    private var pageChangeListener: OnPageChangeListener? = null

    override fun onMultiWindowModeChanged(isInMultiWindowMode: Boolean, newConfig: android.content.res.Configuration) {
        super.onMultiWindowModeChanged(isInMultiWindowMode, newConfig)

        HiveActivity.onMultiWindowModeChanged(this, isInMultiWindowMode, newConfig)
    }

    override fun onConfigurationChanged(newConfig: android.content.res.Configuration) {
        super.onConfigurationChanged(newConfig)

        HiveActivity.onConfigurationChanged(this, newConfig)

    }

    override fun attachBaseContext(newBase: Context?) {
        newBase?.let { super.attachBaseContext(HiveActivity.attachBaseContext(newBase)) }
    }

    override fun onCreate(savedInstanceState: Bundle?) {
        super.onCreate(savedInstanceState)

        Log.i("MainActivity", "onCreate")

        Log.e("MainActivity", "===== mcc: ${this.resources.configuration.mcc}")

        this.requestWindowFeature(android.view.Window.FEATURE_NO_TITLE)

        this.initUi()

        HiveActivity.onCreate(this, savedInstanceState)
    }

    override fun onStart() {
        super.onStart()

        HiveActivity.onStart(this)
    }

    override fun onRestart() {
        super.onRestart()

        HiveActivity.onRestart(this)
    }

    override fun onResume() {
        super.onResume()

        Log.i("MainActivity", "onResume")

        HiveActivity.onResume(this)
    }


    override fun onPause() {

        HiveActivity.onPause(this)

        super.onPause()
    }

    override fun onStop() {
        HiveActivity.onStop(this)

        super.onStop()
    }

    override fun onDestroy() {
        HiveActivity.onDestroy(this)

        releaseViewPager()

        super.onDestroy()
    }

    override fun onWindowFocusChanged(hasFocus: Boolean) {
        super.onWindowFocusChanged(hasFocus)

        HiveActivity.onWindowFocusChanged(this, hasFocus)
    }


    override fun onNewIntent(intent: Intent?) {
        super.onNewIntent(intent)

        Log.i("MainActivity", "onNewIntent")
        HiveActivity.onNewIntent(this, intent)
    }

    override fun onActivityResult(requestCode: Int, resultCode: Int, data: Intent?) {
        HiveActivity.onActivityResult(this, requestCode, resultCode, data)
        super.onActivityResult(requestCode, resultCode, data)
    }


    // Android SDK 6.0 (android-23) API over
    @TargetApi(23)
    override fun onRequestPermissionsResult(requestCode: Int, permissions: Array<String>, grantResults: IntArray) {
        super.onRequestPermissionsResult(requestCode, permissions, grantResults)

        HiveActivity.onRequestPermissionsResult(this, requestCode, permissions, grantResults)
    }


    override fun onSaveInstanceState(outState: Bundle) {
        super.onSaveInstanceState(outState)

        HiveActivity.onSaveInstanceState(this, outState)
    }

    override fun onBackPressed() {
        super.onBackPressed()
    }


    private fun initUi() {

        setContentView(R.layout.main_activity)


        // HiveSDK 설정 대화 상자 노출
        val configurationDialog = ConfigurationDialog(this)
        configurationDialog.showConfigurationDialog(object : ConfigurationDialog.ConfigurationDialogListener {

            override fun onConfigurationSelect(appId: String, hiveCertificationKey: String, zoneType: ZoneType, themeType: com.hive.ui.Configuration.HiveTheme, hiveOrientation: String, gameLanguage: String, gameServerId: String, isLogging: Boolean, loggingUserId: String?, isRemoteLogging: Boolean, isRemoteDetailLogging: Boolean, isAgeGateU13: Boolean) {
                // 설정 대화 상자에서 설정이 완료되면 HiveSDK 설정 을 수행
                Configuration.appId = appId
                Configuration.hiveCertificationKey = hiveCertificationKey
                Configuration.zone = zoneType
                Configuration.hiveTheme = themeType
                Configuration.hiveOrientation = hiveOrientation
                Configuration.gameLanguage = gameLanguage
                Configuration.serverId = gameServerId
                Configuration.useLog = isLogging
//                Configuration.setLogUserId(loggingUserId)
//                Configuration.setIsRemoteLogging(isRemoteLogging)
//                Configuration.setIsRemoteDetailLogging(isRemoteDetailLogging)
                Configuration.ageGateU13 = isAgeGateU13

                Android.runOnMainThread(Runnable { buildViewPager() })
            }
        })
    }

    private fun releaseViewPager() {

        val viewPager = ViewPagerManager.getViewPager()
        if (viewPager != null) {
            viewPager.removeOnPageChangeListener(pageChangeListener!!)

            ViewPagerManager.releaseViewPager()
        }
    }

    private fun buildViewPager() {

        var view: View

        // AuthV4 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_authv4, null)
        ViewPagerManager.addView(AuthV4TestView(this, view, "AuthV4 >>"))

        // AuthV4Helper 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_authv4_helper, null)
        ViewPagerManager.addView(AuthV4HelperTestView(this, view, "AuthV4 >>"))

        // ProviderGoogle 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_provider, null)
        ViewPagerManager.addView(ProviderTestView(this, view, "Provider >>"))

        // 인증 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_auth, null)
        ViewPagerManager.addView(AuthTestView(this, view, "AuthV1 >>"))


        // 소셜 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_social, null)
        ViewPagerManager.addView(SocialTestView(this, view, "<< Social >>"))


        // 프로모션 뷰의 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_promotion, null)
        ViewPagerManager.addView(PromotionTestView(this, view, "<< Promotion >>"))


        // 푸시 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_push, null)
        ViewPagerManager.addView(PushTestView(this, view, "<< Push Notification >>"))


        // IAP (빌링) 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_iap, null)
        ViewPagerManager.addView(IAPTestView(this, view, "<< IAP >>"))


        // IAPV4 (빌링) 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_iapv4, null)
        ViewPagerManager.addView(IAPV4TestView(this, view, "<< IAPV4 >>"))


        // Analytics 테스트 뷰 추가
        view = layoutInflater.inflate(R.layout.test_view_analytics, null)
        ViewPagerManager.addView(AnalyticsTestView(this, view, "Analytics >>"))


        val viewPager = findViewById<View>(R.id.main_pager) as androidx.viewpager.widget.ViewPager
        viewPager.adapter = ViewPagerManager
        ViewPagerManager.setViewPager(this, viewPager)


        //		viewPager.setOnPageChangeListener(new OnPageChangeListener() {

        pageChangeListener = object : OnPageChangeListener {

            override fun onPageSelected(position: Int) {

                ViewPagerManager.onPageChange(position)
            }

            override fun onPageScrolled(arg0: Int, arg1: Float, arg2: Int) {}

            override fun onPageScrollStateChanged(arg0: Int) {}

        }.also {
            viewPager.addOnPageChangeListener(it)
        }

    }
}
